==> httpmaid-jsr356-0.9.68-sources.jar: de/quantummaid/httpmaid/jsr356/Jsr356MessageHandler.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.jsr356;

import de.quantummaid.httpmaid.HttpMaid;
import de.quantummaid.httpmaid.websockets.sender.NonSerializableConnectionInformation;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import javax.websocket.MessageHandler;
import javax.websocket.Session;

import static de.quantummaid.httpmaid.jsr356.SenderHelper.sendMessage;
import static de.quantummaid.httpmaid.websockets.endpoint.RawWebsocketMessage.rawWebsocketMessage;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class Jsr356MessageHandler implements MessageHandler.Whole<String> {
    private final NonSerializableConnectionInformation connectionInformation;
    private final Session session;
    private final HttpMaid httpMaid;

    public static MessageHandler.Whole<String> jsr356MessageHandler(final NonSerializableConnectionInformation connectionInformation,
                                                                    final Session session,
                                                                    final HttpMaid httpMaid) {
        return new Jsr356MessageHandler(connectionInformation, session, httpMaid);
    }

    @Override
    public void onMessage(final String message) {
        httpMaid.handleRequest(
                () -> rawWebsocketMessage(connectionInformation, message),
                response -> response.optionalStringBody()
                        .ifPresent(responseMessage -> sendMessage(session, responseMessage))
        );
    }
}

==> httpmaid-jsr356-0.9.78-sources.jar: de/quantummaid/httpmaid/jsr356/Jsr356MessageHandler.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.jsr356;

import de.quantummaid.httpmaid.HttpMaid;
import de.quantummaid.httpmaid.websockets.sender.NonSerializableConnectionInformation;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import javax.websocket.MessageHandler;
import javax.websocket.Session;

import static de.quantummaid.httpmaid.websockets.endpoint.RawWebsocketMessage.rawWebsocketMessage;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class Jsr356MessageHandler implements MessageHandler.Whole<String> {
    private final NonSerializableConnectionInformation connectionInformation;
    private final Session session;
    private final HttpMaid httpMaid;

    public static MessageHandler.Whole<String> jsr356MessageHandler(final NonSerializableConnectionInformation connectionInformation,
                                                                    final Session session,
                                                                    final HttpMaid httpMaid) {
        return new Jsr356MessageHandler(connectionInformation, session, httpMaid);
    }

    @Override
    public void onMessage(final String message) {
        httpMaid.handleRequest(
                () -> rawWebsocketMessage(connectionInformation, message),
                response -> response.optionalStringBody()
                        .ifPresent(connectionInformation::send)
        );
    }
}
